:py:mod:`icclim._core.generic.generic_templates`
================================================

.. py:module:: icclim._core.generic.generic_templates

.. autoapi-nested-parse::

   Jinja templates for the metadata of generic indices.



Module Contents
---------------

.. py:class:: IndicatorMetadata
